==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkFeatureEdges.java <==
// java wrapper for vtkFeatureEdges object
//

package vtk;
import vtk.*;

public class vtkFeatureEdges extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBoundaryEdges_2(int id0);
  public void SetBoundaryEdges(int id0)
    { SetBoundaryEdges_2(id0); }

  private native int GetBoundaryEdges_3();
  public int GetBoundaryEdges()
    { return GetBoundaryEdges_3(); }

  private native void BoundaryEdgesOn_4();
  public void BoundaryEdgesOn()
    { BoundaryEdgesOn_4(); }

  private native void BoundaryEdgesOff_5();
  public void BoundaryEdgesOff()
    { BoundaryEdgesOff_5(); }

  private native void SetFeatureEdges_6(int id0);
  public void SetFeatureEdges(int id0)
    { SetFeatureEdges_6(id0); }

  private native int GetFeatureEdges_7();
  public int GetFeatureEdges()
    { return GetFeatureEdges_7(); }

  private native void FeatureEdgesOn_8();
  public void FeatureEdgesOn()
    { FeatureEdgesOn_8(); }

  private native void FeatureEdgesOff_9();
  public void FeatureEdgesOff()
    { FeatureEdgesOff_9(); }

  private native void SetFeatureAngle_10(double id0);
  public void SetFeatureAngle(double id0)
    { SetFeatureAngle_10(id0); }

  private native double GetFeatureAngleMinValue_11();
  public double GetFeatureAngleMinValue()
    { return GetFeatureAngleMinValue_11(); }

  private native double GetFeatureAngleMaxValue_12();
  public double GetFeatureAngleMaxValue()
    { return GetFeatureAngleMaxValue_12(); }

  private native double GetFeatureAngle_13();
  public double GetFeatureAngle()
    { return GetFeatureAngle_13(); }

  private native void SetNonManifoldEdges_14(int id0);
  public void SetNonManifoldEdges(int id0)
    { SetNonManifoldEdges_14(id0); }

  private native int GetNonManifoldEdges_15();
  public int GetNonManifoldEdges()
    { return GetNonManifoldEdges_15(); }

  private native void NonManifoldEdgesOn_16();
  public void NonManifoldEdgesOn()
    { NonManifoldEdgesOn_16(); }

  private native void NonManifoldEdgesOff_17();
  public void NonManifoldEdgesOff()
    { NonManifoldEdgesOff_17(); }

  private native void SetManifoldEdges_18(int id0);
  public void SetManifoldEdges(int id0)
    { SetManifoldEdges_18(id0); }

  private native int GetManifoldEdges_19();
  public int GetManifoldEdges()
    { return GetManifoldEdges_19(); }

  private native void ManifoldEdgesOn_20();
  public void ManifoldEdgesOn()
    { ManifoldEdgesOn_20(); }

  private native void ManifoldEdgesOff_21();
  public void ManifoldEdgesOff()
    { ManifoldEdgesOff_21(); }

  private native void SetColoring_22(int id0);
  public void SetColoring(int id0)
    { SetColoring_22(id0); }

  private native int GetColoring_23();
  public int GetColoring()
    { return GetColoring_23(); }

  private native void ColoringOn_24();
  public void ColoringOn()
    { ColoringOn_24(); }

  private native void ColoringOff_25();
  public void ColoringOff()
    { ColoringOff_25(); }

  private native void SetLocator_26(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_26(id0); }

  private native long GetLocator_27();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_27();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_28();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_28(); }

  private native int GetMTime_29();
  public int GetMTime()
    { return GetMTime_29(); }

  private native void SetOutputPointsPrecision_30(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_30(id0); }

  private native int GetOutputPointsPrecision_31();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_31(); }

  public vtkFeatureEdges() { super(); }

  public vtkFeatureEdges(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-9-armv7h.pkg.tar.xz: vtk/vtkFeatureEdges.java <==
// java wrapper for vtkFeatureEdges object
//

package vtk;
import vtk.*;

public class vtkFeatureEdges extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetBoundaryEdges_2(int id0);
  public void SetBoundaryEdges(int id0)
    { SetBoundaryEdges_2(id0); }

  private native int GetBoundaryEdges_3();
  public int GetBoundaryEdges()
    { return GetBoundaryEdges_3(); }

  private native void BoundaryEdgesOn_4();
  public void BoundaryEdgesOn()
    { BoundaryEdgesOn_4(); }

  private native void BoundaryEdgesOff_5();
  public void BoundaryEdgesOff()
    { BoundaryEdgesOff_5(); }

  private native void SetFeatureEdges_6(int id0);
  public void SetFeatureEdges(int id0)
    { SetFeatureEdges_6(id0); }

  private native int GetFeatureEdges_7();
  public int GetFeatureEdges()
    { return GetFeatureEdges_7(); }

  private native void FeatureEdgesOn_8();
  public void FeatureEdgesOn()
    { FeatureEdgesOn_8(); }

  private native void FeatureEdgesOff_9();
  public void FeatureEdgesOff()
    { FeatureEdgesOff_9(); }

  private native void SetFeatureAngle_10(double id0);
  public void SetFeatureAngle(double id0)
    { SetFeatureAngle_10(id0); }

  private native double GetFeatureAngleMinValue_11();
  public double GetFeatureAngleMinValue()
    { return GetFeatureAngleMinValue_11(); }

  private native double GetFeatureAngleMaxValue_12();
  public double GetFeatureAngleMaxValue()
    { return GetFeatureAngleMaxValue_12(); }

  private native double GetFeatureAngle_13();
  public double GetFeatureAngle()
    { return GetFeatureAngle_13(); }

  private native void SetNonManifoldEdges_14(int id0);
  public void SetNonManifoldEdges(int id0)
    { SetNonManifoldEdges_14(id0); }

  private native int GetNonManifoldEdges_15();
  public int GetNonManifoldEdges()
    { return GetNonManifoldEdges_15(); }

  private native void NonManifoldEdgesOn_16();
  public void NonManifoldEdgesOn()
    { NonManifoldEdgesOn_16(); }

  private native void NonManifoldEdgesOff_17();
  public void NonManifoldEdgesOff()
    { NonManifoldEdgesOff_17(); }

  private native void SetManifoldEdges_18(int id0);
  public void SetManifoldEdges(int id0)
    { SetManifoldEdges_18(id0); }

  private native int GetManifoldEdges_19();
  public int GetManifoldEdges()
    { return GetManifoldEdges_19(); }

  private native void ManifoldEdgesOn_20();
  public void ManifoldEdgesOn()
    { ManifoldEdgesOn_20(); }

  private native void ManifoldEdgesOff_21();
  public void ManifoldEdgesOff()
    { ManifoldEdgesOff_21(); }

  private native void SetColoring_22(int id0);
  public void SetColoring(int id0)
    { SetColoring_22(id0); }

  private native int GetColoring_23();
  public int GetColoring()
    { return GetColoring_23(); }

  private native void ColoringOn_24();
  public void ColoringOn()
    { ColoringOn_24(); }

  private native void ColoringOff_25();
  public void ColoringOff()
    { ColoringOff_25(); }

  private native void SetLocator_26(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_26(id0); }

  private native long GetLocator_27();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_27();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_28();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_28(); }

  private native int GetMTime_29();
  public int GetMTime()
    { return GetMTime_29(); }

  private native void SetOutputPointsPrecision_30(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_30(id0); }

  private native int GetOutputPointsPrecision_31();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_31(); }

  public vtkFeatureEdges() { super(); }

  public vtkFeatureEdges(long id) { super(id); }
  public native long   VTKInit();

}
